@@ -23,8 +23,8 @@ class TestCase(unittest.TestCase):
         """
 
         return skos.Concepts([
-                skos.Concept('uri1', 'prefLabel1', 'definition1'),
-                skos.Concept('uri2', 'prefLabel2', 'definition2')
+                skos.Concept('uri1', 'prefLabel1', 'definition1', 'notation1'),
+                skos.Concept('uri2', 'prefLabel2', 'definition2', 'notation2')
             ])
 
     def createDbSchema(self):
@@ -64,7 +64,17 @@ class TestConcept(TestCase):
     """
 
     def getTestObj(self):
-        return skos.Concept('uri', 'prefLabel', 'definition')
+        return skos.Concept('uri', 'prefLabel', 'definition', 'notation')
+
+    def testEqual(self):
+        self.assertEqual(self.obj, self.getTestObj())
+        other = skos.Concept('other uri', 'other prefLabel', 'other definition', 'other notation')
+        self.assertNotEqual(self.obj, other)
+
+        # compare against an instance with a different interface. Use
+        # `assertFalse` as `assertNotEqual` seems to catch
+        # `AttributeErrors`.
+        self.assertFalse(self.obj == 'other object')
 
     def testInheritance(self):
         super(TestConcept, self).doTestInheritance()
