@@ -6,6 +6,7 @@ import skos
 from test import unittest
 import rdflib
 import os.path
+import datetime
 
 class TestRDFUriNormalisation(unittest.TestCase):
     """
@@ -75,6 +76,10 @@ class TestRDFLoader(TestCase):
         self.assertEqual(len(concepts), 3)
         for concept in concepts.itervalues():
             self.assertIsInstance(concept, skos.Concept)
+            self.assertGreater(len(concept.uri), 1)
+            self.assertGreater(len(concept.prefLabel), 1)
+            self.assertGreater(len(concept.definition), 1)
+            self.assertGreater(len(concept.notation), 1)
 
     def testGetConceptSchemes(self):
         schemes = self.loader.getConceptSchemes()
@@ -89,6 +94,9 @@ class TestRDFLoader(TestCase):
         self.assertEqual(len(collections), 1)
         for collection in collections.itervalues():
             self.assertIsInstance(collection, skos.Collection)
+            self.assertGreater(len(collection.title), 1)
+            self.assertGreater(len(collection.description), 1)
+            self.assertIsInstance(collection.date, datetime.datetime)
 
     def testFlattening(self):
         self.loader.flat = True
